@@ -704,8 +704,9 @@ class DataSetMetaData:
 
         config_dataset["encoding"] = encoding
 
+        database_name = config["davt_database_name"]
         full_dataset_name = (
-            "davt_" + project_id + "_" + environment + "." + dataset_name
+            database_name + "." + dataset_name
         )
         config_dataset["full_dataset_name"] = full_dataset_name
 
