@@ -118,10 +118,7 @@ class DataSetCrud:
             dd_param = ""
 
         dataset_name_list = full_dataset_name.split(".")
-        if dataset_name_list[0] is not None:
-            database_name = dataset_name_list[0]
-        else:
-            database_name = None
+        database_name = config["davt_database_name"]
 
         if dataset_name_list[1] is not None:
             dataset_name = dataset_name_list[1]
